NetworkClient class abstract
Abstract interface for the network client.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getRetryAfterTime(
) → DateTime? - Get the time when we can retry after rate limiting.
-
isRateLimited(
) → bool - Check if we're currently rate limited.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendEvents(
EventsPayload payload, MGMConfiguration config) → Future< SendResult> - Send events to the API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited